/******************************************************************************
 * Whisper_Command - Whisper a message to a single Player.
 * $Id: Whisper_Command.java,v 1.5 2011/06/24 01:52:33 dick Exp $
 * 
 * jIBS - A Java clone of FIBS
 * Copyright 2002 - Axel Leucht
 * Copyright 2011 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Whisper_Command.java,v $
 * Revision 1.5  2011/06/24 01:52:33  dick
 * Implement whisper per the spec.
 *
 * Revision 1.4  2011/06/09 18:19:18  dick
 * Use Player.println() instead of the JibsWriter.
 *
 * Revision 1.3  2011/06/02 19:26:46  dick
 * informWatcher() becomes informWatchers().
 *
 * Revision 1.2  2011/05/31 13:02:43  dick
 * Bucko headers.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is jIBS, <https://sourceforge.net/projects/fibs/>.
 * The Initial Developer of the Original Code is Axel Leucht.
 * 
 */
package net.sourceforge.jibs.command;

import net.sourceforge.jibs.backgammon.BackgammonBoard;
import net.sourceforge.jibs.backgammon.JibsGame;
import net.sourceforge.jibs.server.JibsServer;
import net.sourceforge.jibs.server.Player;
import net.sourceforge.jibs.util.ClipConstants;

/** Whisper a message to all watchers.
 *
 * @author Axel Leucht
 * @author Dick Balaska
 * @version $Revision: 1.5 $ <br> $Date: 2011/06/24 01:52:33 $
 * @see <a href="http://cvs.buckosoft.com/Projects/jIBS/jIBS/src/main/java/net/sourceforge/jibs/command/Whisper_Command.java">cvs Whisper_Command.java</a>
 * @see <a href="http://www.fibs.com/fibs_interface.html#whisper">Whisper definition</a>
 */
public class Whisper_Command implements JibsCommand {

	@Override
	public boolean execute(JibsServer jibsServer, Player player,
			String strArgs, String[] args) {
		String msg;
		JibsGame game = player.getGame();
		if (game == null && player.getWatchingPlayer() != null) 
			game = player.getWatchingPlayer().getGame();

		if (game != null) {
			BackgammonBoard board = game.getBackgammonBoard();
			Player player1 = board.getPlayerX();
			Player player2 = board.getPlayerO();
			player.println(ClipConstants.CLIP_YOU_WHISPER + " " + strArgs);

			msg = ClipConstants.CLIP_WHISPERS + " " + player.getName() +
			" " + strArgs;
			int heard = player1.show2Watchers(msg, player)
					  + player2.show2Watchers(msg, player);
			if (heard != 0)
				player.println("** " + heard + " user" + (heard != 1 ? "s" : "") +  " heard you.");
			else {
				msg = jibsServer.getJibsMessages().convert("m_whisper_no_heard");
				player.println(msg);
			}
			return (true);
		}
		// m_kibitz_no_play=** You're not watching or playing.
		msg = jibsServer.getJibsMessages().convert("m_kibitz_no_play");
		player.println(msg);
		return(true);
	}
}
